#!/usr/bin/env python
#
# mdvinput
#
# Written  by Kendall Weaver <kendalltweaver@gmail.com> and Ikey Doherty <contactjfreak@googlemail.com>
# Modifed by Alexander Kazancev <kazancas@gmail.com>
# Graphical settings tool written for the Mandriva LXDE edition
# to replace lxinput with a single, better
# featured application.
import sys

APP="mdvinput"
DIR="/usr/share/locale"

try:
	import pygtk
	pygtk.require("2.0")
except:
	print "You do not have the required PyGTK version."
	sys.exit(1)
try:
	import gtk
	import os
	import gettext
	import ConfigParser
	import getpass
	import locale
except:
	print "You do not have the required dependencies"
	sys.exit(1)

# This is needed to make gtk.Builder work by specifying the
# translations directory
locale.bindtextdomain(APP, DIR)
 
gettext.bindtextdomain(APP, DIR)
gettext.textdomain(APP)

try:
	lang = gettext.translation(APP, DIR)
	_ = lang.gettext
except:
	print "WARNING: No translations found for your language, using default"

gettext.install(APP, DIR)

class mdvinput:
	def __init__(self):
		
		self.glade = '/usr/share/mdvinput/mdvinput.glade'
		self.builder = gtk.Builder()
		self.builder.set_translation_domain(APP)
		self.builder.add_from_file(self.glade)
		self.window = self.builder.get_object("dlg")
		self.window.set_title(_("Keyboard, Mouse and Touchpad"))
		self.window.connect("destroy", gtk.main_quit)
		self.window.show()

		#read config file

		config = ConfigParser.RawConfigParser()
		config.add_section('Mouse')
		config.add_section('Keyboard')
		config.add_section('Touchpad')
		cur_user = getpass.getuser()
		conf_file_name = '/home/' + cur_user + '/.config/lxsession/LXDE/desktop.conf'
		
		#touch file. If not, copy from /etc/xdg/lxsession/LXDE
		
		if not (os.path.exists(conf_file_name)):
			os.system('mkdir -p /home/' + cur_user + '/.config/lxsession/LXDE/')
			os.system('cp -f /etc/xdg/lxsession/LXDE/desktop.conf /home/' + cur_user + '/.config/lxsession/LXDE/')
		
		config.read(conf_file_name)
		
		# keyboard delay
		delay = self.builder.get_object("kb_delay")
		delay.set_range(100, 1100)
		delay.set_increments(100, 100)
		delay.set_digits(0)
		delay.set_value(config.getint('Keyboard', 'Delay'))

		# interval
		interval = self.builder.get_object("kb_interval")
		interval.set_range(1, 200)
		interval.set_increments(1, 1)
		interval.set_digits(0)
		interval.set_value(config.getint('Keyboard', 'Interval'))

		# touchpad
		self.builder.get_object("touchpad_disable").set_active(config.getboolean('Touchpad', 'Disable'))
		self.builder.get_object("vertical_scroll").set_active(config.getboolean('Touchpad', 'VertScoll'))
		self.builder.get_object("touchpad_type_off").set_active(config.getboolean('Touchpad', 'TypeOff'))
		self.builder.get_object("horizontal_scroll").set_active(config.getboolean('Touchpad', 'HorizScroll'))
		self.builder.get_object("tap_to_click").set_active(config.getboolean('Touchpad', 'TapToClick'))
		
		self.builder.get_object("touchpad_disable").connect("clicked", self.touchpad_cb)
		self.builder.get_object("vertical_scroll").connect("clicked", self.touchpad_vertical)
		self.builder.get_object("horizontal_scroll").connect("clicked", self.touchpad_horizontal)
		self.builder.get_object("tap_to_click").connect("clicked", self.touchpad_tap)
		
		# off delay with type
		tp_interval = self.builder.get_object("touchpad_type_delay")
		tp_interval.set_range(100, 2000)
		tp_interval.set_increments(100, 1000)
		tp_interval.set_digits(0)
		tp_interval.set_value(config.getint('Touchpad', 'TypeTime'))

		# accel.
		accel = self.builder.get_object("mouse_accel")
		accel.set_range(0, 10)
		accel.set_increments(1, 2)
		accel.set_digits(0)
		mouse_value = config.getint('Mouse', 'AccFactor')/10
		accel.set_value(mouse_value)
		# threshold
		threshold = self.builder.get_object("mouse_threshold")
		threshold.set_range(0, 10)
		threshold.set_increments(1, 2)
		threshold.set_digits(0)
		mouse_threshold = config.getint('Mouse', 'AccThreshold')/10
		threshold.set_value(mouse_threshold)
		
		#left button
		
		self.builder.get_object("left_handed").set_active(config.getboolean('Mouse', 'LeftHanded'))
		
		#connect signals of button
		self.builder.get_object("cancel").connect("clicked", gtk.main_quit)
		self.builder.get_object("ok").connect("clicked", self.apply_cb)


	def touchpad_cb(self, w):
		pad = str("synclient TouchPadOff=%d" % (int(w.get_active())))
		os.system(pad)

	def touchpad_vertical(self, w):
		vert = str("synclient VertEdgeScroll=%d" % (int(w.get_active())))
		os.system(vert)

	def touchpad_horizontal(self, w):
		horiz = str("synclient HorizEdgeScroll=%d" % (int(w.get_active())))
		os.system(horiz)

	def touchpad_tap(self, w):
		tap = str("synclient TapButton1=$d" % (int(w.get_active())))
		os.system(tap)

	''' apply all settings '''
	def apply_cb(self, widget):
			# keyboard stuff.
			w = self.builder.get_object("kb_delay")
			delay = int(w.get_value())
			w = self.builder.get_object("kb_interval")
			interval = 51 - int(w.get_value())
			
			#impliment setting now
			os.system('echo "set keyboard"')
			os.system('xset r rate ' + str(delay) + ' ' + str(interval))
			
			# mouse stuff.
			w = self.builder.get_object("mouse_threshold")
			threshold = int(w.get_value())
			w = self.builder.get_object("mouse_accel")
			accel = int(w.get_value())

			# left handed?
			w = self.builder.get_object("left_handed")
			paw = str("pointer = 1 2 3")
			if(w.get_active()):
				paw = str("pointer = 3 2 1")
			#impliment setting now
			os.system('echo "set mouse"')
			os.system('xmodmap -e \"' + paw + '\"')
			os.system('echo "set keyboard"')
			os.system('xset m ' + str(accel) + ' ' + str(threshold))
			os.system('echo "set touchpad"')
			
			#touchpad stuff
			if(self.builder.get_object("touchpad_type_off").get_active()):
				os.system('syndaemon -kdi ' + str(self.builder.get_object("touchpad_type_delay").get_value()));

			# save the settings in LXDE session conf
			from configobj import ConfigObj
			
			ms_threshold = self.builder.get_object("mouse_threshold")
			ms_accel = self.builder.get_object("mouse_accel")
			kb_interval = self.builder.get_object("kb_interval")
			kb_delay = self.builder.get_object("kb_delay")
			type_delay = self.builder.get_object("touchpad_type_delay")
			
			
			cur_user = getpass.getuser()
			config = ConfigObj('/home/' + cur_user + '/.config/lxsession/LXDE/desktop.conf')
			
			#set mouse config
			mouse_section = config['Mouse']
			
			mouse_section['AccThreshold'] = str(int(ms_threshold.get_value() * 10))
			mouse_section['AccFactor'] = str(int(ms_accel.get_value() * 10))
			mouse_section['LeftHanded'] = str(int(self.builder.get_object("left_handed").get_active()))
			
			#set keyboard config
			kb_section = config['Keyboard']
			kb_section['Interval'] = str(int(kb_interval.get_value()))
			kb_section['Delay'] = str(int(kb_delay.get_value()))
			
			#set touchpad config
			tp_section = config['Touchpad']
			tp_section['Disable'] = str(int(self.builder.get_object("touchpad_disable").get_active()))
			tp_section['VertScoll'] = str(int(self.builder.get_object("vertical_scroll").get_active()))
			tp_section['TypeOff'] = str(int(self.builder.get_object("touchpad_type_off").get_active()))
			tp_section['HorizScroll'] = str(int(self.builder.get_object("horizontal_scroll").get_active()))
			tp_section['TapToClick'] = str(int(self.builder.get_object("tap_to_click").get_active()))
			tp_section['TypeTime'] = str(int(type_delay.get_value()))
			
			config.write()
			
			# delete spaces between and after =
			os.system('sed -i s/\ =\ /=/ '+ '/home/' + cur_user + '/.config/lxsession/LXDE/desktop.conf')

if __name__ == "__main__":
	mdvinput()
	gtk.main()

